#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SPLAT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SPLAT_HPP_INCLUDED

#include <boost/simd/memory/include/functions/simd/splat.hpp>

#endif
